##  Visualizing Milestones in Reports
Milestones are visible in the Roadmap Reports, every time the Initiative (Project) is the primary Fact Sheet or is present as a drill-down. This allows stakeholders to have a clear and comprehensive overview of the progress of the Initiative, by offering a visual representation of significant achievements
Hovering over a Milestone displays more context for the icon, such as the name and target date. To always display this context, you can check the Show labels of milestones option in the report settings. When exporting the report, the context will be retained if you have chosen to show labels of option.
![Show labels of milestones](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2750f3f97a44101491a6f0a9cfa7af3c_LowRes.png)
Show labels of milestones
All reports with a timeline also display milestone icons when an Initiative/Project is projected on the timeline. The timeline starts with the earliest date among all projects and concludes with the most recent date. In the absence of a specific date, the fallback is set to one year.
![Milestones in the timeline of reports](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27533ae97a4410149e68e05cde440e03_LowRes.gif)
Milestones in the timeline of reports
YesNo
Send
